Index: CHANGES
===================================================================
--- CHANGES	(revision 276613)
+++ CHANGES	(working copy)
@@ -230,6 +230,7 @@
  * Added option to dialplan function CDR(), the 'f' option
    allows for high resolution times for billsec and duration fields.
  * FILE() now supports line-mode and writing.
+ * Added FIELDNUM, which returns the position number of a field in a list.
 
 Dialplan Variables
 ------------------
Index: funcs/func_strings.c
===================================================================
--- funcs/func_strings.c	(revision 276613)
+++ funcs/func_strings.c	(working copy)
@@ -61,6 +61,24 @@
 			<para>Example: If ${example} contains <literal>ex-amp-le</literal>, then ${FIELDQTY(example,-)} returns 3.</para>
 		</description>
 	</function>
+	<function name="FIELDNUM" language="en_US">
+		<synopsis>
+			Return the position number of a field in a list 
+		</synopsis>
+		<syntax>
+			<parameter name="varname" required="true" />
+			<parameter name="delim" required="true" />
+			<parameter name="value" required="true" />
+		</syntax>
+		<description>
+			<para>The delimiter may be specified as a special or extended ASCII character, by encoding it.  The characters
+			<literal>\n</literal>, <literal>\r</literal>, and <literal>\t</literal> are all recognized as the newline,
+			carriage return, and tab characters, respectively.  Also, octal and hexadecimal specifications are recognized
+			by the patterns <literal>\0nnn</literal> and <literal>\xHH</literal>, respectively.  For example, if you wanted
+			to encode a comma as the delimiter, you could use either <literal>\054</literal> or <literal>\x2C</literal>.</para>
+		<para>Example: If ${example} contains <literal>ex-amp-le</literal>, then ${FIELDNUM(example,-,amp)} returns 2.</para>
+		</description>
+	</function>
 	<function name="LISTFILTER" language="en_US">
 		<synopsis>Remove an item from a list, by name.</synopsis>
 		<syntax>
@@ -455,6 +473,58 @@
 	.read2 = function_fieldqty_str,
 };
 
+static int function_fieldnum(struct ast_channel *chan, const char *cmd,
+                             char *parse, char *buf, size_t len)
+{
+	char *varsubst, *field;
+	struct ast_str *str = ast_str_thread_get(&result_buf, 16);
+	int fieldindex = 0;
+	AST_DECLARE_APP_ARGS(args,
+		AST_APP_ARG(varname);
+		AST_APP_ARG(delim);
+		AST_APP_ARG(field);
+	);
+	char delim[2] = "";
+	size_t delim_used;
+
+	AST_STANDARD_APP_ARGS(args, parse);
+	if (args.argc < 3) {
+		ast_log(LOG_ERROR, "Usage: FIELDNUM(<listname>,<delimiter>,<fieldvalue>)\n");
+		return -1;
+	}
+
+	ast_get_encoded_char(args.delim, delim, &delim_used);
+
+	varsubst = alloca(strlen(args.varname) + 4);
+	sprintf(varsubst, "${%s}", args.varname);
+
+	ast_str_substitute_variables(&str, 0, chan, varsubst);
+	if (ast_str_strlen(str) == 0) {
+		fieldindex = 0;
+	} else {
+		char *varval = ast_str_buffer(str);
+
+		while ((field = strsep(&varval, delim)) != NULL) {
+			fieldindex++;
+
+			if (!strcasecmp(field, args.field)) {
+				break;
+			}
+		}
+		if (!field) {
+			fieldindex = 0;
+		}
+	}
+	snprintf(buf, len, "%d", fieldindex);
+
+	return 0;
+}
+
+static struct ast_custom_function fieldnum_function = {
+        .name = "FIELDNUM",
+        .read = function_fieldnum,
+};
+
 static int listfilter(struct ast_channel *chan, const char *cmd, char *parse, char *buf, struct ast_str **bufstr, ssize_t len)
 {
 	AST_DECLARE_APP_ARGS(args,
